
package se.conciliate.documents.impl.test.diskdrive;

import java.awt.event.ActionEvent;
import java.io.File;
import java.util.ArrayList;
import java.util.List;
import java.util.function.Consumer;
import javax.swing.AbstractAction;
import javax.swing.Action;
import javax.swing.DefaultListModel;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.ListSelectionModel;
import se.conciliate.documents.impl.test.diskdrive.DiskDriveSettings.DiskDrivePath;
import se.conciliate.mt.tools.URLS;
import se.conciliate.mt.ui.UISwingUtils;
import se.conciliate.mt.ui.UIToolBar;
import se.conciliate.mt.ui.laf.HiDpiIcon;
import se.conciliate.mt.ui.renderers.UIListCellRenderer;

/**
 * The UI where DiskDriveSettings are edited. To change this UI you may need Netbeans, or
 * rewrite the UI in its entirety.
 */
public class DiskDriveSettingsEditor extends javax.swing.JPanel {
    private final JFrame frame;
    private final Consumer<String> callback;
    private Action removePathAction;
    
    public DiskDriveSettingsEditor(JFrame frame, Consumer<String> callback, DiskDriveSettings current) {
        this.frame = frame;
        this.callback = callback;
        
        initComponents();
        
        jLabel2.setText("Disk drive documents");
        jLabel2.setIcon(new HiDpiIcon(URLS.createURL("icon:o24/hard_drive.png")));
        
        DefaultListModel pathModel = new DefaultListModel();
        current.getPaths().forEach(pathModel::addElement);
        listPaths.setModel(pathModel);
        listPaths.setSelectionMode(ListSelectionModel.MULTIPLE_INTERVAL_SELECTION);
        listPaths.setCellRenderer(new UIListCellRenderer() {
            @Override
            public void updateRendererComponent(JLabel label, Object value) {
                if(value instanceof DiskDrivePath) {
                    DiskDrivePath path = (DiskDrivePath)value;
                    label.setText(path.getPath());
                    label.setIcon(new HiDpiIcon(URLS.createURL("icon:o24/folder.png")));
                }
            }
        });
        
        addPathActions();
        listPaths.addListSelectionListener(evt -> {
            if(!evt.getValueIsAdjusting()) {
                removePathAction.setEnabled(evt.getFirstIndex() >= 0);
            }
        });
    }
    
    private void addPathActions() {
        UIToolBar tb = (UIToolBar)jToolBar1;
        
        tb.addTop(new AbstractAction("", new HiDpiIcon(URLS.createURL("icon:o24/plus.png"))) {
            @Override
            public void actionPerformed(ActionEvent e) {
                File file = UISwingUtils.selectDirectory(frame, null, "Select path", "Select");
                if(file != null) {
                    DiskDrivePath path = new DiskDrivePath(file.getAbsolutePath(), true, false);
                    ((DefaultListModel)listPaths.getModel()).addElement(path);
                }
            }
        });
        tb.addTop(removePathAction = new AbstractAction("", new HiDpiIcon(URLS.createURL("icon:o24/delete.png"))) {
            { setEnabled(false); }
            @Override
            public void actionPerformed(ActionEvent e) {
                List toRemove = listPaths.getSelectedValuesList();
                toRemove.forEach(element -> ((DefaultListModel)listPaths.getModel()).removeElement(element));
            }
        });
    }

    /**
     * This method is called from within the constructor to initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is always
     * regenerated by the Form Editor.
     */
    @SuppressWarnings("unchecked")
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        jLabel2 = new javax.swing.JLabel();
        jScrollPane1 = new javax.swing.JScrollPane();
        listPaths = new javax.swing.JList<>();
        jToolBar1 = new UIToolBar(UIToolBar.VERTICAL);
        jLabel1 = new javax.swing.JLabel();
        jButton1 = new javax.swing.JButton();

        jLabel2.setFont(jLabel2.getFont().deriveFont(jLabel2.getFont().getStyle() | java.awt.Font.BOLD, jLabel2.getFont().getSize()+2));
        jLabel2.setText("Connecting...");

        listPaths.setModel(new javax.swing.AbstractListModel<String>() {
            String[] strings = { "Item 1", "Item 2", "Item 3", "Item 4", "Item 5" };
            public int getSize() { return strings.length; }
            public String getElementAt(int i) { return strings[i]; }
        });
        jScrollPane1.setViewportView(listPaths);

        jToolBar1.setFloatable(false);
        jToolBar1.setRollover(true);

        jLabel1.setText("Source directories:");

        jButton1.setText("Save settings");
        jButton1.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                jButton1ActionPerformed(evt);
            }
        });

        javax.swing.GroupLayout layout = new javax.swing.GroupLayout(this);
        this.setLayout(layout);
        layout.setHorizontalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(layout.createSequentialGroup()
                .addContainerGap()
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addGroup(layout.createSequentialGroup()
                        .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                            .addComponent(jScrollPane1, javax.swing.GroupLayout.PREFERRED_SIZE, 459, javax.swing.GroupLayout.PREFERRED_SIZE)
                            .addComponent(jLabel1))
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addComponent(jToolBar1, javax.swing.GroupLayout.PREFERRED_SIZE, 36, javax.swing.GroupLayout.PREFERRED_SIZE))
                    .addGroup(layout.createSequentialGroup()
                        .addComponent(jLabel2)
                        .addGap(18, 18, 18)
                        .addComponent(jButton1)))
                .addGap(0, 26, Short.MAX_VALUE))
        );
        layout.setVerticalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(layout.createSequentialGroup()
                .addContainerGap()
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(jLabel2)
                    .addComponent(jButton1))
                .addGap(18, 18, 18)
                .addComponent(jLabel1)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addComponent(jScrollPane1, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addComponent(jToolBar1, javax.swing.GroupLayout.PREFERRED_SIZE, 130, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addContainerGap(78, Short.MAX_VALUE))
        );
    }// </editor-fold>//GEN-END:initComponents

    private void jButton1ActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_jButton1ActionPerformed
        List<DiskDrivePath> paths = new ArrayList<>();
        DefaultListModel pathModel = (DefaultListModel)listPaths.getModel();
        for(int i = 0; i < pathModel.getSize(); i++) {
            paths.add((DiskDrivePath)pathModel.getElementAt(i));
        }
        
        callback.accept(new DiskDriveSettings(paths).toJson());
    }//GEN-LAST:event_jButton1ActionPerformed


    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JButton jButton1;
    private javax.swing.JLabel jLabel1;
    private javax.swing.JLabel jLabel2;
    private javax.swing.JScrollPane jScrollPane1;
    private javax.swing.JToolBar jToolBar1;
    private javax.swing.JList<String> listPaths;
    // End of variables declaration//GEN-END:variables
}
