package se.conciliate.documents.impl.test.diskdrive;

import java.io.File;
import java.nio.file.Path;
import se.conciliate.extensions.documents.DocumentFilter;
import se.conciliate.extensions.documents.DocumentFilterType;
import se.conciliate.extensions.store.MTLanguage;
import se.conciliate.extensions.store.query.FilterEditorType;

public class DiskPatternFilter implements DocumentFilter, DiskFilter {
    private final String pattern;
    private final MTLanguage language;
    private final boolean exactMatch;
    private final boolean ignoreCase;

    public DiskPatternFilter(String pattern, MTLanguage language, boolean exactMatch, boolean ignoreCase) {
        this.pattern = pattern;
        this.language = language;
        this.exactMatch = exactMatch;
        this.ignoreCase = ignoreCase;
    }
    
    @Override
    public boolean isMatch(Path path) {
        String a = ignoreCase ? path.getFileName().toString().toLowerCase() : path.getFileName().toString();
        String b = ignoreCase ? pattern.toLowerCase() : pattern;
        
        if(exactMatch) {
            return a.equals(b);
        } else {
            return a.contains(b);
        }
    }

    public MTLanguage getLanguage() {
        return language;
    }

    public boolean isExactMatch() {
        return exactMatch;
    }

    public boolean isIgnoreCase() {
        return ignoreCase;
    }
    
    @Override
    public boolean isFiltering() {
        return !pattern.isBlank();
    }
    
    @Override
    public String getFilterString() {
        return pattern;
    }

    @Override
    public String getFilterRepresentation() {
        return pattern;
    }

    @Override
    public FilterEditorType getEditorType() {
        return FilterEditorType.NONE;
    }
    
    @Override
    public DocumentFilterType getFilterType() {
        return null;
    }
    
}
